@@ -38,7 +38,7 @@ import (
 	collectioncommon "github.com/apache/incubator-answer/internal/service/collection_common"
 	"github.com/apache/incubator-answer/internal/service/config"
 	"github.com/apache/incubator-answer/internal/service/export"
-	"github.com/apache/incubator-answer/internal/service/meta"
+	"github.com/apache/incubator-answer/internal/service/meta_common"
 	"github.com/apache/incubator-answer/internal/service/notice_queue"
 	"github.com/apache/incubator-answer/internal/service/notification"
 	"github.com/apache/incubator-answer/internal/service/permission"
@@ -71,7 +71,7 @@ type QuestionService struct {
 	userRepo                         usercommon.UserRepo
 	userRoleRelService               *role.UserRoleRelService
 	revisionService                  *revision_common.RevisionService
-	metaService                      *meta.MetaService
+	metaService                      *metacommon.MetaCommonService
 	collectionCommon                 *collectioncommon.CollectionCommon
 	answerActivityService            *activity.AnswerActivityService
 	emailService                     *export.EmailService
@@ -92,7 +92,7 @@ func NewQuestionService(
 	userRepo usercommon.UserRepo,
 	userRoleRelService *role.UserRoleRelService,
 	revisionService *revision_common.RevisionService,
-	metaService *meta.MetaService,
+	metaService *metacommon.MetaCommonService,
 	collectionCommon *collectioncommon.CollectionCommon,
 	answerActivityService *activity.AnswerActivityService,
 	emailService *export.EmailService,
