@@ -20,7 +20,7 @@
 import { useEffect, useState } from 'react';
 
 import { minimalSetup } from 'codemirror';
-import { EditorState } from '@codemirror/state';
+import { EditorState, Compartment } from '@codemirror/state';
 import { EditorView, placeholder } from '@codemirror/view';
 import { markdown, markdownLanguage } from '@codemirror/lang-markdown';
 import { languages } from '@codemirror/language-data';
@@ -29,6 +29,7 @@ import { Editor } from '../types';
 
 import createEditorUtils from './extension';
 
+const editableCompartment = new Compartment();
 export function htmlRender(el: HTMLElement | null) {
   if (!el) return;
   // Replace all br tags with newlines
@@ -80,26 +81,23 @@ export const useEditor = ({
   const [editor, setEditor] = useState<Editor | null>(null);
   const [value, setValue] = useState<string>('');
   const init = async () => {
-    const theme = EditorView.theme(
-      {
-        '&': {
-          height: '100%',
-        },
-        '&.cm-focused': {
-          outline: 'none',
-        },
-        '.cm-content': {
-          width: '100%',
-          padding: '1rem',
-        },
-        '.cm-line': {
-          whiteSpace: 'pre-wrap',
-          wordWrap: 'break-word',
-          wordBreak: 'break-all',
-        },
+    const theme = EditorView.theme({
+      '&': {
+        height: '100%',
       },
-      { dark: false },
-    );
+      '&.cm-focused': {
+        outline: 'none',
+      },
+      '.cm-content': {
+        width: '100%',
+        padding: '1rem',
+      },
+      '.cm-line': {
+        whiteSpace: 'pre-wrap',
+        wordWrap: 'break-word',
+        wordBreak: 'break-all',
+      },
+    });
 
     const startState = EditorState.create({
       extensions: [
@@ -111,6 +109,7 @@ export const useEditor = ({
         theme,
         placeholder(placeholderText),
         EditorView.lineWrapping,
+        editableCompartment.of(EditorView.editable.of(true)),
       ],
     });
 
@@ -121,6 +120,14 @@ export const useEditor = ({
 
     const cm = createEditorUtils(view as Editor);
 
+    cm.setReadOnly = (readOnly: boolean) => {
+      cm.dispatch({
+        effects: editableCompartment.reconfigure(
+          EditorView.editable.of(!readOnly),
+        ),
+      });
+    };
+
     if (autoFocus) {
       setTimeout(() => {
         cm.focus();
@@ -150,9 +157,13 @@ export const useEditor = ({
   }, [value]);
 
   useEffect(() => {
-    if (!(editorRef.current instanceof HTMLElement) || editor) {
+    if (!editorRef.current) {
       return;
     }
+    if (editorRef.current.children.length > 0 || editor) {
+      return;
+    }
+
     init();
   }, [editor]);
   return editor;
